@@ -17,6 +17,9 @@
 # Error with CAM signature/authentication.
 AUTHFAILURE = 'AuthFailure'
 
+# Token verification failed.
+AUTHFAILURE_TOKENFAILURE = 'AuthFailure.TokenFailure'
+
 # `DryRun` Operation. It means that the request would have succeeded, but the `DryRun` parameter was used.
 DRYRUNOPERATION = 'DryRunOperation'
 
@@ -155,6 +158,9 @@ RESOURCESSOLDOUT = 'ResourcesSoldOut'
 # Unauthorized operation.
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# Role not authorized.
+UNAUTHORIZEDOPERATION_ROLEUNAUTHORIZED = 'UnauthorizedOperation.RoleUnAuthorized'
+
 # Unverified user.
 UNAUTHORIZEDOPERATION_UNAUTHORIZEDACCOUNT = 'UnauthorizedOperation.UnauthorizedAccount'
 
@@ -163,3 +169,6 @@ UNKNOWNPARAMETER = 'UnknownParameter'
 
 # Unsupported operation.
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
+# Account not bound.
+UNSUPPORTEDOPERATION_ACCOUNTNOTBOUND = 'UnsupportedOperation.AccountNotBound'
